@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -19,7 +19,7 @@ from beartype.typing import (
     Set,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._check.convert.convcoerce import clear_coerce_hint_caches
+from beartype._check.checkcache import clear_checker_caches
 from beartype._conf.confcls import BeartypeConf
 from beartype._data.cls.datacls import TYPES_BEARTYPEABLE
 from beartype._data.hint.datahinttyping import (
@@ -131,87 +131,6 @@ def beartype_type(
     # Else, this decorator has yet to decorate this class.
 
     # ....................{ LOCALS                         }....................
-    # Fully-qualified name of the module defining this class if this class is
-    # defined by a module *OR* "None" otherwise (e.g., if this class is only
-    # dynamically defined in-memory outside of any module structure).
-    module_name = get_object_module_name_or_none(cls)
-
-    # If this class is defined by a module...
-    if module_name:
-        # Unqualified basename of this class.
-        type_name = cls.__name__
-
-        # Set of the unqualified basenames of *ALL* classes in that module
-        # previously decorated by this decorator.
-        type_names_beartyped = _BEARTYPED_MODULE_TO_TYPE_NAME[module_name]
-
-        # If a class with the same unqualified basename defined in a module with
-        # the same fully-qualified name has already been marked as decorated by
-        # this decorator, then either:
-        # * That module has been externally reloaded. In this case, this class
-        #   (along with the remainder of that module) has now been redefined.
-        #   Common examples include:
-        #   * Rerunning a Jupyter cell defining this class.
-        #   * Refreshing a web app enabling hot reloading (i.e., automatic
-        #     reloading of on-disk modules whose contents have been externally
-        #     modified *AFTER* that app was initially run). Since most Python
-        #     web app frameworks (e.g., Flask, Streamlit) support hot reloading,
-        #     this is the common case.
-        # * That module has internally redefined this class two or more times.
-        #   This behaviour, while typically a bug, is also technically valid:
-        #   e.g.,
-        #       @beartype
-        #       def MuhClass(object): ...
-        #       @beartype
-        #       def MuhClass(object): ...   # <-- this makes me squint
-        #
-        # In this case, clear *ALL* beartype-specific internal caches that have
-        # been shown to fail when a class is redefined.
-        if type_name in type_names_beartyped:
-            #FIXME: Consider emitting a logging message instead if this branch
-            #ever becomes computationally intensive, please.
-            # print(f'@beartyped class "{module_name}.{type_name}" redefined!')
-
-            # Clear the previously accessed set of the unqualified basenames of
-            # *ALL* classes in that module previously decorated by this
-            # decorator. Technically, this is optional. Pragmatically, this
-            # *SHOULD* significantly improve the space and time constraints
-            # associated with this class redefinition. Why? Because this class
-            # being redefined implies that the module defining this class is
-            # being redefined, which implies that all classes in that module are
-            # being redefined as well. If we did *NOT* clear this set here, then
-            # this set would continue to contain the unqualified basenames of
-            # those other classes in that module; each @beartype-decorated
-            # redefinition of those other classes would then unnecessarily clear
-            # the same caches already cleared by the first @beartype-decorated
-            # redefinition of a class in that module. Since doing so would be
-            # overly aggressive and thus inefficient, avoiding doing so improves
-            # efficiency in the common case of module redefinition.
-            _BEARTYPED_MODULE_TO_TYPE_NAME.clear()
-
-            # Clear *ALL* type hint coercion caches, which map from the
-            # machine-readable representations of previously seen
-            # non-self-cached type hints (e.g., "list[MuhClass]") to the first
-            # seen instance of those hints (e.g., list[MuhClass]). Since this
-            # class has been redefined, the first seen instance of those hints
-            # could contain a reference to the first definition of this class;
-            # if so, there now exists a discrepancy between the current
-            # definition of this class and cached hints containing the prior
-            # definition of this class. For safety, all caches possibly
-            # containing those hints must now be assumed to be invalid. Failing
-            # to clear these caches causes @beartype-decorated wrapper functions
-            # to raise erroneous type-checking violations. See also:
-            #     https://github.com/beartype/beartype/issues/288
-            clear_coerce_hint_caches()
-        # Else, this is the first decoration of this class by this decorator.
-        # In this case...
-        else:
-            # Record that this class has now been decorated by this decorator.
-            # Technically, this should (probably) be performed *AFTER* this
-            # decorator has actually successfully decorated this class.
-            # Pragmatically, doing so here is simply faster and... simpler.
-            type_names_beartyped.add(type_name)
-    # Else, this class is *NOT* defined by a module.
 
     # Replace the passed class stack with a new class stack appending this
     # decorated class to the top of this stack, reflecting the fact that this
@@ -234,11 +153,114 @@ def beartype_type(
     )
 
     # ....................{ DECORATION                     }....................
+    # Clear *ALL* beartype-specific internal caches that have been shown to fail
+    # when a class is redefined if the passed class is detected as having been
+    # redefined in its module.
+    _uncache_beartype_if_type_redefined(cls)
+
     # For the unqualified name and value of each direct (i.e., *NOT* indirectly
     # inherited) attribute of this class...
     for attr_name, attr_value in cls.__dict__.items():  # pyright: ignore[reportGeneralTypeIssues]
-        # If this attribute is beartypeable...
-        if isinstance(attr_value, TYPES_BEARTYPEABLE):
+        # True only if this attribute is directly beartypeable (e.g., is either
+        # a function, class, or builtin method descriptor).
+        is_attr_beartypeable = isinstance(attr_value, TYPES_BEARTYPEABLE)
+
+        # If this attribute is *NOT* directly beartypeable (e.g., is neither a
+        # function, class, nor builtin method descriptor), this attribute
+        # *COULD* still be indirectly beartypeable. How? By being a non-standard
+        # object implemented by some third-party package wrapping a standard
+        # object that *is* directly beartypeable. Although the original use case
+        # was non-standard function wrappers implemented by the third-party
+        # Equinox package, this logic transparently generalizes to *ALL*
+        # third-party packages. Consequently, *ALL* third-party packages
+        # defining non-standard objects wrapping standard objects should
+        # endeavour to support @beartype by reproducing the general-purpose
+        # solution that Equinox adopted.
+        #
+        # Notably, third-party packages should ideally add "support for such
+        # monkey-patching, by adding a __setattr__() that checks for functions
+        # and wraps them into one of Equinox's function-wrappers." See also:
+        #     https://github.com/patrick-kidger/equinox/issues/584#issuecomment-1806260288
+        #
+        # Specifically, if this attribute is *NOT* directly beartypeable...
+        if not is_attr_beartypeable:
+            # Uncomment to debug this insanity. *sigh*
+            # attr_value_old = attr_value
+
+            # Override the previously retrieved static value of this attribute
+            # (i.e., the direct value of this attribute *WITHOUT* regard to
+            # dynamic descriptor lookup, which in the case of a standard
+            # descriptor builtin like @classmethod is that C-based @classmethod
+            # descriptor itself) with the dynamic value of this attribute
+            # (i.e., the indirect value of this attribute *WITH* regard to
+            # dynamic descriptor lookup, which in the case of a standard
+            # descriptor builtin like @classmethod is the pure-Python function
+            # wrapped by that C-based @classmethod descriptor) if this attribute
+            # supports the descriptor protocol *OR* reduce to a noop otherwise.
+            attr_value = getattr(cls, attr_name)
+
+            # True only if this attribute is directly beartypeable.
+            is_attr_beartypeable = isinstance(attr_value, TYPES_BEARTYPEABLE)
+        # Else, this attribute is directly beartypeable.
+
+        # If this attribute is...
+        if (
+            # Now directly beartypeable *AND*...
+            is_attr_beartypeable and
+            # It is *NOT* the case that...
+            #
+            # Note that this condition intentionally excludes class variables
+            # whose values are types from consideration, thus preventing
+            # @beartype from erroneously decorating those types. Why? Because
+            # the caller did *NOT* explicitly instruct us to decorate those
+            # types. Moreover, attempting to do so can ignite infinite recursion
+            # in common edge cases and is thus fundamentally dangerous.
+            #
+            # Consider this sample user-defined class:
+            #     class ParentClass(object):
+            #         class_var: type = type
+            #         class NestedClass(object):
+            #             pass
+            #
+            # Syntactically, the class variable "ParentClass.class_var" and
+            # nested class "ParentClass.NestedClass" share *NO* commonality.
+            # Semantically, however, @beartype treats those two attributes of
+            # the parent class "ParentClass" as effectively identical. The
+            # values of those two attributes are both classes, which @beartype
+            # typically tries to recursively decorate. But only the latter are
+            # safely decoratable by @beartype.
+            #
+            # Class variables whose values are types are *NOT* safely
+            # decoratable by @beartype. In the best case, doing so would
+            # decorate external classes *NOT* intended to be decorated; in the
+            # worst case, doing so would provoke infinite recursion. Indeed, the
+            # worst case is exactly what once happened. Previously, decorating
+            # concrete "enum.Enum" subclasses with @beartype once provoked
+            # infinite recursion. Why? Because:
+            #
+            # * *All* :class:`enum.Enum` subclasses define a private
+            #   "_member_type_" attribute whose value is the "object"
+            #   superclass, which @beartype then decorated.
+            # * However, the :class:`object` superclass defines the "__class__"
+            #   dunder attribute whose value is the "type" superclass, which
+            #   @beartype then decorated.
+            # * However, the "type" superclass defines the "__base__" dunder
+            #   attribute whose value is the "object" superclass, which
+            #   @beartype then decorated.
+            # * *INFINITE FRIGGIN' RECURSION*. Anarchy today.
+            #
+            # In both the best and worst cases above, class variables whose
+            # values are types *CANNOT* be safely decorated by @beartype.
+            not (
+                # This attribute is a class *AND*...
+                isinstance(attr_value, type) and
+                # This class was declared elsewhere and merely defined here as a
+                # class attribute of the currently decorated class whose value
+                # is this class (rather than as a nested class of the currently
+                # decorated class)...
+                not attr_value.__qualname__.startswith(cls.__qualname__)
+            )
+        ):
             # This attribute decorated with type-checking configured by this
             # configuration if *NOT* already decorated.
             attr_value_beartyped = beartype_object(
@@ -291,3 +313,117 @@ fully-qualified name of each module defining one or more classes decorated by
 the :func:`beartype.beartype` decorator to the set of the unqualified basenames
 of all classes in that module decorated by that decorator).
 '''
+
+# ....................{ PRIVATE ~ globals                  }....................
+def _uncache_beartype_if_type_redefined(cls: type) -> None:
+    '''
+    Clear *all* :mod:`beartype`-specific internal caches that have been shown to
+    fail when a class is redefined if the passed class is detected as having
+    been redefined in its module.
+
+    If a class with the same unqualified basename defined in a module with the
+    same fully-qualified name has already been marked as decorated by this
+    decorator, then either:
+
+    * That module has been externally reloaded. In this case, this class (along
+      with the remainder of that module) has now been redefined. Common examples
+      include:
+
+      * Rerunning a Jupyter cell defining this class.
+      * Refreshing a web app enabling hot reloading (i.e., automatic reloading
+        of on-disk modules whose contents have been externally modified *after*
+        that app was initially run). Since most Python web app frameworks (e.g.,
+        Flask, Streamlit) support hot reloading, this is the common case.
+
+    * That module has internally redefined this class two or more times. This
+      behaviour, while typically a bug, is also technically valid: e.g.,
+
+      .. code-block:: python
+
+         @beartype
+         def MuhClass(object): ...
+         @beartype
+         def MuhClass(object): ...   # <-- this makes me squint
+
+    In either case, this class has been redefined. Since :mod:`beartype` has no
+    efficient means of deciding which internal caches to clear in response,
+    :mod:`beartype` instead now unconditionally clears *all* internal caches.
+    Doing so incurs a minor performance penalty whenever a module reload occurs
+    while preserving user-facing usability across module reloads. In short, the
+    minor performance penalty is worth this major usability gain.
+    '''
+
+    # Fully-qualified name of the module defining this class if this class is
+    # defined by a module *OR* "None" otherwise (e.g., if this class is only
+    # dynamically defined in-memory outside of any module structure).
+    module_name = get_object_module_name_or_none(cls)
+
+    # If this class is defined by a module...
+    if module_name:
+        # Unqualified basename of this class.
+        type_name = cls.__name__
+
+        # Set of the unqualified basenames of *ALL* classes in that module
+        # previously decorated by this decorator.
+        type_names_beartyped = _BEARTYPED_MODULE_TO_TYPE_NAME[module_name]
+
+        # If a class with the same unqualified basename defined in a module with
+        # the same fully-qualified name has already been marked as decorated by
+        # this decorator, then this class is currently being redefined. In this
+        # case, clear *ALL* beartype-specific internal caches that have been
+        # shown to fail when classes are redefined.
+        if type_name in type_names_beartyped:
+            #FIXME: Consider emitting a logging message instead if this branch
+            #ever becomes computationally intensive, please.
+            # print(f'@beartyped class "{module_name}.{type_name}" redefined!')
+
+            # Clear the previously accessed set of the unqualified basenames of
+            # *ALL* classes in that module previously decorated by this
+            # decorator. Technically, this is optional. Pragmatically, this
+            # *SHOULD* significantly improve the space and time constraints
+            # associated with this class redefinition. Why? Because this class
+            # being redefined implies that the module defining this class is
+            # being redefined, which implies that all classes in that module are
+            # being redefined as well. If we did *NOT* clear this set here, then
+            # this set would continue to contain the unqualified basenames of
+            # those other classes in that module; each @beartype-decorated
+            # redefinition of those other classes would then unnecessarily clear
+            # the same caches already cleared by the first @beartype-decorated
+            # redefinition of a class in that module. Since doing so would be
+            # overly aggressive and thus inefficient, avoiding doing so improves
+            # efficiency in the common case of module redefinition.
+            _BEARTYPED_MODULE_TO_TYPE_NAME.clear()
+
+            # Clear *ALL* type-checking caches. Notably:
+            # * The forward reference referee cache (i.e., private
+            #   "beartype._check.forward.reference.fwdrefmeta._forwardref_to_referee"
+            #   dictionary) is problematic, due to mapping from forward
+            #   reference proxies (which are themselves classes) to arbitrary
+            #   (and thus usually user-defined) classes -- one or more of which
+            #   might be this class or other similarly redefined classes.
+            # * The type hint coercion cache (i.e., private
+            #   "beartype._check.convert.convcoerce._hint_repr_to_hint"
+            #   dictionary) is problematic, due to mapping from the
+            #   machine-readable representations of previously seen
+            #   non-self-cached type hints (e.g., "list[MuhClass]") to the first
+            #   seen instance of those hints (e.g., list[MuhClass]). Since this
+            #   class has been redefined, the first seen instance of those hints
+            #   could contain a reference to the first definition of this class.
+            #
+            # If any of these caches contain such desynchronized key-value
+            # pairs, there now exists a discrepancy between the current
+            # definition of this class and existing references in these caches
+            # to the prior definition of this class. For safety, all caches
+            # possibly containing those references must now be assumed to be
+            # invalid. Failing to clear these caches causes @beartype-decorated
+            # wrapper functions to raise erroneous type-checking violations.
+            clear_checker_caches()
+        # Else, this is the first decoration of this class by this decorator.
+        # In this case...
+        else:
+            # Record that this class has now been decorated by this decorator.
+            # Technically, this should (probably) be performed *AFTER* this
+            # decorator has actually successfully decorated this class.
+            # Pragmatically, doing so here is simply faster and... simpler.
+            type_names_beartyped.add(type_name)
+    # Else, this class is *NOT* defined by a module.
