@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -11,17 +11,20 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype.roar._roarexc import _BeartypeUtilCallableException
+from beartype.roar._roarexc import (
+    _BeartypeUtilCallableScopeException,
+    _BeartypeUtilCallableScopeNotFoundException,
+)
 from beartype.typing import (
     Any,
     Optional,
 )
 from beartype._util.utilobject import get_object_basename_scoped
-from beartype._data.datakind import DICT_EMPTY
 from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeException,
 )
+from beartype._data.kind.datakinddict import DICT_EMPTY
 from collections.abc import Callable
 from types import CodeType
 
@@ -32,7 +35,7 @@ def get_func_globals(
     func: Callable,
 
     # Optional parameters.
-    exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_cls: TypeException = _BeartypeUtilCallableScopeException,
 ) -> LexicalScope:
     '''
     **Global scope** (i.e., a dictionary mapping from the name to value of each
@@ -59,15 +62,15 @@ def get_func_globals(
         the passed callable. Defaults to 0.
     exception_cls : Type[Exception], optional
         Type of exception to be raised in the event of a fatal error. Defaults
-        to :class:`_BeartypeUtilCallableException`.
+        to :class:`._BeartypeUtilCallableScopeException`.
 
     Returns
-    ----------
+    -------
     Dict[str, Any]
         Global scope for this callable.
 
     Raises
-    ----------
+    ------
     exception_cls
         If this callable is a wrapper wrapping a C-based rather than
         pure-Python wrappee callable.
@@ -76,7 +79,7 @@ def get_func_globals(
 
     # Avoid circular import dependencies.
     from beartype._util.func.utilfunctest import die_unless_func_python
-    from beartype._util.func.utilfuncwrap import unwrap_func_all_closures_isomorphic
+    from beartype._util.func.utilfuncwrap import unwrap_func_all_isomorphic
 
     # If this callable is *NOT* pure-Python, raise an exception. C-based
     # callables do *NOT* define the "__globals__" dunder attribute.
@@ -84,7 +87,7 @@ def get_func_globals(
     # Else, this callable is pure-Python.
 
     # Lowest-level wrappee callable wrapped by this wrapper callable.
-    func_wrappee = unwrap_func_all_closures_isomorphic(func)
+    func_wrappee = unwrap_func_all_isomorphic(func)
 
     # Dictionary mapping from the name to value of each locally scoped
     # attribute accessible to this wrappee callable to be returned.
@@ -102,7 +105,7 @@ def get_func_locals(
     # Optional parameters.
     func_scope_names_ignore: int = 0,
     func_stack_frames_ignore: int = 0,
-    exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_cls: TypeException = _BeartypeUtilCallableScopeException,
 ) -> LexicalScope:
     '''
     **Local scope** for the passed callable.
@@ -143,7 +146,7 @@ def get_func_locals(
     has yet to be declared and thus added to the call stack.
 
     Caveats
-    ----------
+    -------
     **This high-level getter requires the private low-level**
     :func:`sys._getframe` **getter.** If that getter is undefined, this getter
     unconditionally treats the passed callable as module-scoped by returning the
@@ -181,18 +184,23 @@ def get_func_locals(
         the passed callable. Defaults to 0.
     exception_cls : Type[Exception], optional
         Type of exception to be raised in the event of a fatal error. Defaults
-        to :class:`_BeartypeUtilCallableException`.
+        to :class:`._BeartypeUtilCallableScopeException`.
 
     Returns
-    ----------
+    -------
     LexicalScope
         Local scope for this callable.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
         If the next non-ignored frame following the last ignored frame is *not*
         the parent callable or module directly declaring the passed callable.
+    _BeartypeUtilCallableScopeNotFoundException
+        If this lexical scope cannot be found (i.e., if this getter found the
+        lexical scope of the module declaring the passed callable *before* that
+        of the parent callable or class declaring that callable), enabling
+        callers to identify this common edge case.
     '''
     assert callable(func), f'{repr(func)} not callable.'
     assert isinstance(func_scope_names_ignore, int), (
@@ -445,9 +453,9 @@ def get_func_locals(
         # Because that scope *MUST* necessarily be in the same module as that
         # of this nested callable. In this case, raise an exception.
         if func_frame_name == FUNC_CODEOBJ_NAME_MODULE:
-            raise exception_cls(
+            raise _BeartypeUtilCallableScopeNotFoundException(
                 f'{func_name_qualified}() parent lexical scope '
-                f'{func_scope_name}() not found on call stack.'
+                f'"{func_scope_name}" not found on call stack.'
             )
         # Else, that scope is *NOT* a module.
         #
@@ -525,13 +533,13 @@ def add_func_scope_attr(
         exception message. Defaults to the empty string.
 
     Returns
-    ----------
+    -------
     str
         Name of the passed object in this scope generated by this function.
 
     Raises
-    ----------
-    :exc:`._BeartypeUtilCallableException`
+    ------
+    _BeartypeUtilCallableScopeException
         If an attribute with the same name as that internally generated by
         this adder but having a different value already exists in this scope.
         This adder uniquifies names by object identifier and should thus
@@ -577,7 +585,7 @@ def add_func_scope_attr(
     # If an attribute with the same name but differing value already exists in
     # this scope, raise an exception.
     if func_scope.get(attr_name, attr) is not attr:
-        raise _BeartypeUtilCallableException(
+        raise _BeartypeUtilCallableScopeException(
             f'{exception_prefix}"{attr_name}" already exists with '
             f'differing value:\n'
             f'~~~~[ NEW VALUE ]~~~~\n{repr(attr)}\n'
@@ -600,7 +608,7 @@ Arbitrary substring prefixing names dynamically synthesized by the
 the integers returned by the :func:`id` builtin) are positive.
 
 See Also
-----------
+--------
 :data:`._ATTR_NAME_PREFIX_ID_NEGATIVE`
     Further details.
 '''
