@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -28,7 +28,7 @@ from beartype._conf.confcls import BeartypeConf
 from beartype._util.ast.utilastget import get_node_repr_indented
 from beartype._util.text.utiltextlabel import label_exception
 from importlib import (  # type: ignore[attr-defined]
-    _bootstrap_external,  # pyright: ignore[reportGeneralTypeIssues]
+    _bootstrap_external,  # pyright: ignore
 )
 from importlib.machinery import SourceFileLoader
 from importlib.util import decode_source
@@ -439,7 +439,7 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         # that module as is by simply deferring to the superclass method.
         if self._module_conf_beartype is None:
             return super().source_to_code(  # type: ignore[call-arg]
-                data=data, path=path, _optimize=_optimize)  # pyright: ignore[reportGeneralTypeIssues]
+                data=data, path=path, _optimize=_optimize)  # pyright: ignore
         # Else, that module has been registered for type-checking.
 
         # Plaintext decoded contents of that module.
@@ -465,10 +465,17 @@ class BeartypeSourceFileLoader(SourceFileLoader):
         module_ast_beartyped = ast_beartyper.visit(module_ast)
 
         #FIXME: Conditionally perform this logic if "conf.is_debug", please.
+        #Note that printing to "stderr" is pivotal. For some reason, Python
+        #fails to forward printing to "stdout" across subprocesses even when we
+        #explicitly tell it to. Look. I don't even know. Just roll with it!
+        # from sys import stderr
         # print(
-        #     f'Module "{self._module_name_beartype}" abstract syntax tree (AST) '
-        #     f'transformed by @beartype to:\n\n'
-        #     f'{get_node_repr_indented(module_ast_beartyped)}'
+        #     (
+        #         f'Module "{self._module_name_beartype}" abstract syntax tree (AST) '
+        #         f'transformed by @beartype to:\n\n'
+        #         f'{get_node_repr_indented(module_ast_beartyped)}'
+        #     ),
+        #     file=stderr,
         # )
 
         # Attempt to...
