@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -209,7 +209,7 @@ if _PYTHON_VERSION_PARTS < PYTHON_VERSION_MIN_PARTS:
 # For further details, see http://semver.org.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-VERSION = '0.16.2'
+VERSION = '0.17.2'
 '''
 Human-readable package version as a ``.``-delimited string.
 '''
@@ -250,7 +250,7 @@ attribution, see the `contributors graph`_ for this project.
 '''
 
 
-COPYRIGHT = '2014-2023 Beartype authors'
+COPYRIGHT = '2014-2024 Beartype authors'
 '''
 Legally binding copyright line excluding the license-specific prefix (e.g.,
 ``"Copyright (c)"``).
@@ -414,6 +414,9 @@ requirements strings of the format ``{project_name}
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 LIBS_TESTTIME_OPTIONAL = (
+    # Required by optional Equinox-specific integration tests.
+    'equinox',
+
     # Require a reasonably recent version of mypy known to behave well. Less
     # recent versions are significantly deficient with respect to error
     # reporting and *MUST* thus be blacklisted.
@@ -480,6 +483,12 @@ LIBS_TESTTIME_OPTIONAL = (
     #     Deprecated call to `pkg_resources.declare_namespace('sphinxcontrib')`.
     'sphinx; python_version >= "3.8.0"',
 
+    #FIXME: Temporarily disabled for sanity.
+    # Required by optional PyTorch-specific integration tests.
+    #
+    # Note that PyTorch has yet to release a Python >= 3.12-compatible version.
+    # 'torch; python_version < "3.12.0"',
+
     # Required to exercise third-party backports of type hint factories
     # published by the standard "typing" module under newer versions of Python.
     (
