@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -26,6 +26,7 @@ This submodule unit tests :pep:`563` support implemented in the
 # an "from __future__ import annotations" import.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from beartype_test._util.mark.pytskip import (
+    # skip,
     skip_if_pypy,
     skip_if_python_version_greater_than_or_equal_to,
 )
@@ -59,8 +60,8 @@ def test_pep563_class_self_reference_reloaded() -> None:
     # .....................{ IMPORTS                       }....................
     # Defer test-specific imports.
     #
-    # Note that the "data_pep563_club" submodule is intentionally imported as
-    # an attribute rather than importing the requisite attributes from that
+    # Note that the "data_pep563_club" submodule is intentionally imported as an
+    # attribute rather than importing the requisite attributes from that
     # submodule. Why? Because the entire intention of this test is to exercise
     # reloading of @beartype-decorated callables annotated with circular
     # references under PEP 563.
@@ -125,47 +126,33 @@ def test_pep563_class_self_reference_override() -> None:
     # expected value.
     assert Karma.if_your_colors().dreams == DREAMS
 
-
-def test_pep563_func_return() -> None:
-    '''
-    Test module-scoped :pep:`563` support implemented in the
-    :func:`beartype.beartype` decorator with respect to callables with returns
-    annotated by the :pep:`484`-compliant :obj:`typing.NoReturn` type hint.
-    '''
-
-    # Defer test-specific imports.
-    from beartype_test.a00_unit.data.pep.pep563.data_pep563_club import (
-        HeWouldLingerLong,
-        to_love_and_wonder,
-    )
-    from pytest import raises
-
-    # Assert that a @beartype-decorated function "typing.NoReturn" return
-    # annotation is postponed under PEP 563 to a string raises the expected
-    # exception.
-    with raises(HeWouldLingerLong):
-        to_love_and_wonder()
-
-# ....................{ TESTS ~ poem                       }....................
+# ....................{ TESTS ~ scope                      }....................
 def test_pep563_module() -> None:
     '''
     Test module-scoped :pep:`563` support implemented in the
     :func:`beartype.beartype` decorator.
     '''
 
+    # ....................{ IMPORTS                        }....................
     # Defer test-specific imports.
     from beartype import beartype
+    from beartype.roar import BeartypeDecorHintPep604Exception
+    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
     from beartype_test.a00_unit.data.pep.pep563.data_pep563_poem import (
         get_minecraft_end_txt,
+        get_minecraft_end_txt_pep604,
         get_minecraft_end_txt_stanza,
     )
+    from pytest import raises
 
+    # ....................{ LOCALS                         }....................
     # Dictionary of these callables' annotations, localized to enable debugging
     # in the likely event of unit test failure. *sigh*
     GET_MINECRAFT_END_TXT_ANNOTATIONS = get_minecraft_end_txt.__annotations__
     GET_MINECRAFT_END_TXT_STANZA_ANNOTATIONS = (
         get_minecraft_end_txt_stanza.__annotations__)
 
+    # ....................{ ASSERTS                        }....................
     # Assert that all annotations of a callable *NOT* decorated by @beartype
     # are postponed under PEP 563 as expected.
     assert all(
@@ -203,6 +190,23 @@ def test_pep563_module() -> None:
     # Assert that this callable works under PEP 563.
     assert isinstance(get_minecraft_end_txt_typed(player_name='Notch'), str)
 
+    # ....................{ ASSERTS ~ pep 604              }....................
+    # If the active Python interpreter targets Python >= 3.10 and thus supports
+    # PEP 604...
+    if IS_PYTHON_AT_LEAST_3_10:
+        # Manually decorate a PEP 604-compliant callable with @beartype.
+        get_minecraft_end_txt_typed = beartype(get_minecraft_end_txt_pep604)
+
+        # Assert that this callable works under PEP 563.
+        assert isinstance(get_minecraft_end_txt_typed(player_name='Notch'), str)
+    # Else, the active Python interpreter targets Python < 3.10 and thus fails
+    # to support PEP 604. In this case..
+    else:
+        # Assert that attempting to manually decorate a PEP 604-compliant
+        # callable with @beartype raises the expected exception.
+        with raises(BeartypeDecorHintPep604Exception):
+            beartype(get_minecraft_end_txt_pep604)
+
 
 def test_pep563_class() -> None:
     '''
@@ -322,6 +326,54 @@ def test_pep563_closure_nested() -> None:
     assert minecraft_end_txt_inner[0] == (
         'It is reading our thoughts as though they were words on a screen.')
 
+# .....................{ TESTS ~ pep 484                   }....................
+def test_pep563_hint_pep484_namedtuple() -> None:
+    '''
+    Test module-scoped :pep:`563` support implemented in the
+    :func:`beartype.beartype` decorator with respect to :pep:`484`-compliant
+    :obj:`typing.NamedTuple` subclasses decorated by this decorator.
+    '''
+
+    # .....................{ IMPORTS                       }....................
+    # Defer test-specific imports.
+    from beartype.roar import BeartypeCallHintParamViolation
+    from beartype_test.a00_unit.data.pep.pep563.pep484.data_pep563_pep484 import (
+        LeadOnlyTo)
+    from pytest import raises
+
+    # .....................{ PASS                          }....................
+    # Assert that instantiating this subclass with valid fields creates and
+    # returns an object of the expected type exposing the same fields.
+    while_deaths_blue_vault = LeadOnlyTo(0xCAFEFACE)
+    assert while_deaths_blue_vault.a_black_and_watery_depth == 0xCAFEFACE
+
+    # .....................{ FAIL                          }....................
+    # Assert that instantiating this subclass with one or more invalid fields
+    # raises the expected exception.
+    with raises(BeartypeCallHintParamViolation):
+        LeadOnlyTo("While death's blue vault, with loathliest vapours hung,")
+
+
+def test_pep563_hint_pep484_noreturn() -> None:
+    '''
+    Test module-scoped :pep:`563` support implemented in the
+    :func:`beartype.beartype` decorator with respect to callables with returns
+    annotated by the :pep:`484`-compliant :obj:`typing.NoReturn` type hint.
+    '''
+
+    # Defer test-specific imports.
+    from beartype_test.a00_unit.data.pep.pep563.data_pep563_club import (
+        HeWouldLingerLong,
+        to_love_and_wonder,
+    )
+    from pytest import raises
+
+    # Assert that a @beartype-decorated function "typing.NoReturn" return
+    # annotation is postponed under PEP 563 to a string raises the expected
+    # exception.
+    with raises(HeWouldLingerLong):
+        to_love_and_wonder()
+
 # ....................{ TESTS ~ limit                      }....................
 #FIXME: Hilariously, we can't even unit test whether the
 #beartype._decor._pep.pep563._die_if_hint_repr_exceeds_child_limit() function
