@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -20,8 +20,11 @@ from beartype.typing import (
 )
 from beartype._util.func.utilfuncmake import make_func
 from contextlib import contextmanager
-from functools import lru_cache
 from enum import Enum
+from functools import (
+    lru_cache,
+    wraps,
+)
 from sys import exc_info
 
 # ....................{ CLASSES                            }....................
@@ -58,6 +61,16 @@ class Class(object):
     Arbitrary pure-Python class defining arbitrary methods.
     '''
 
+    # ....................{ NESTED                         }....................
+    class NestedClass(object):
+        '''
+        Arbitrary pure-Python **nested class** whose definition is nested inside
+        the definition of another class.
+        '''
+
+        pass
+
+    # ....................{ METHODS                        }....................
     def instance_method(self):
         '''
         Arbitrary pure-Python instance method.
@@ -188,16 +201,7 @@ class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
     pass
 
 # ....................{ CLASSES ~ with : module name       }....................
-class ClassWithModuleNameNone(object):
-    '''
-    Arbitrary pure-Python class with a **missing module name** (i.e., whose
-    ``__module__`` dunder attribute is :data:`None`).
-    '''
-
-    pass
-
-
-class ClassWithModuleNameNonexistent(object):
+class ClassModuleNameFake(object):
     '''
     Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
     ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
@@ -207,10 +211,18 @@ class ClassWithModuleNameNonexistent(object):
     pass
 
 
+class ClassModuleNameNone(object):
+    '''
+    Arbitrary pure-Python class with a **missing module name** (i.e., whose
+    ``__module__`` dunder attribute is :data:`None`).
+    '''
+
+    pass
+
+
 # Monkey-patch the above classes with "bad" module names.
-ClassWithModuleNameNone.__module__ = None
-ClassWithModuleNameNonexistent.__module__ = (
-    'If_I.were.a_dead_leaf.thou_mightest.bear')
+ClassModuleNameFake.__module__ = 'If_I.were.a_dead_leaf.thou_mightest.bear'
+ClassModuleNameNone.__module__ = None
 
 # ....................{ CALLABLES ~ async : factory        }....................
 # Note that we intentionally avoid declaring a factory function for deprecated
@@ -285,6 +297,17 @@ def function_in_memory():
 Arbitrary pure-Python function dynamically declared in-memory.
 ''')
 
+
+@wraps(function)
+def wrapper_isomorphic(*args, **kwargs):
+    '''
+    **Isomorphic wrapper** (i.e., higher-level function transparently preserving
+    both the positions and types of all parameters and returns passed to the
+    lowel-level wrappee callable).
+    '''
+
+    return function(*args, **kwargs)
+
 # ....................{ CALLABLES ~ sync : decorator       }....................
 def decorator(func: Callable) -> Callable:
     '''
@@ -307,15 +330,12 @@ def decorator_isomorphic(func):
     parameters passed to the passed callable).
     '''
 
-    # Defer decorator-specific imports.
-    from functools import wraps
-
     @wraps(func)
     def _closure_isomorphic(*args, **kwargs):
         '''
         **Isomorphic decorator closure** (i.e., closure transparently
-        preserving both the positions and types of all parameters passed to the
-        decorated callable).
+        preserving both the positions and types of all parameters and returns
+        passed to the decorated callable).
         '''
 
         return func(*args, **kwargs)
@@ -427,7 +447,7 @@ sync_generator = sync_generator_factory()
 Arbitrary pure-Python synchronous generator.
 '''
 
-# ....................{ CALLABLES ~ sync : module          }....................
+# ....................{ CALLABLES ~ sync : library         }....................
 @contextmanager
 def context_manager_factory(obj: object) -> Iterator[object]:
     '''
@@ -448,6 +468,30 @@ def lru_cache_func(n: int) -> int:
 
     return n + 1
 
+# ....................{ CALLABLES ~ sync : module          }....................
+def function_module_name_fake() -> None:
+    '''
+    Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
+    ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
+    exist on the local filesystem).
+    '''
+
+    pass
+
+
+def function_module_name_none() -> None:
+    '''
+    Arbitrary pure-Python function with a **missing module name** (i.e., whose
+    ``__module__`` dunder attribute is :data:`None`).
+    '''
+
+    pass
+
+
+# Monkey-patch the above callables with "bad" module names.
+function_module_name_fake.__module__ = 'He_had.a_mask.like_Castlereagh'
+function_module_name_none.__module__ = None
+
 # ....................{ CONSTANTS                          }....................
 CALLABLE_CODE_OBJECT = function.__code__
 '''
