@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -40,21 +40,22 @@ from beartype_test.a00_unit.data.data_type import (
     # OtherSubclassSubclass,
     context_manager_factory,
 )
-from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
-    HintPepMetadata,
-    HintPithSatisfiedMetadata,
-    HintPithUnsatisfiedMetadata,
+from collections.abc import (
+    Callable as CallableABC,
+    Hashable as HashableABC,
+    MutableSequence as MutableSequenceABC,
+    Sequence as SequenceABC,
+    Sized as SizedABC,
 )
-from collections import abc as collections_abc
 from typing import (
     Any,
     AnyStr,
     BinaryIO,
-    ByteString,
     Callable,
     Container,
     ContextManager,
     Dict,
+    ForwardRef,
     Generic,
     Hashable,
     IO,
@@ -145,7 +146,7 @@ class _Pep484GenericUntypevaredDeepSingle(List[List[str]]):
 
 # ....................{ PRIVATE ~ generics : multiple      }....................
 class _Pep484GenericUntypevaredMultiple(
-    collections_abc.Callable, ContextManager[str], Sequence[str]):
+    CallableABC, ContextManager[str], Sequence[str]):
     '''
     :pep:`484`-compliant user-defined generic subclassing multiple
     unparametrized :mod:`typing` types *and* a non-:mod:`typing` abstract base
@@ -214,7 +215,7 @@ class _Pep484GenericTypevaredShallowMultiple(Iterable[T], Container[T]):
 
 
 class _Pep484GenericTypevaredDeepMultiple(
-    collections_abc.Sized, Iterable[Tuple[S, T]], Container[Tuple[S, T]]):
+    SizedABC, Iterable[Tuple[S, T]], Container[Tuple[S, T]]):
     '''
     :pep:`484`-compliant user-defined generic subclassing multiple indirectly
     parametrized :mod:`typing` types *and* a non-:mod:`typing` abstract base
@@ -254,16 +255,13 @@ _TEST_PEP484_FORWARDREF_TYPE = Subclass
 Arbitrary class referred to by :data:`_PEP484_FORWARDREF_CLASSNAME`.
 '''
 
-# ....................{ ADDERS                             }....................
-def add_data(data_module: 'ModuleType') -> None:
+# ....................{ FIXTURES                           }....................
+def hints_pep484_meta() -> 'List[HintPepMetadata]':
     '''
-    Add :pep:`484`-compliant type hint test data to various global containers
-    declared by the passed module.
-
-    Parameters
-    ----------
-    data_module : ModuleType
-        Module to be added to.
+    List of :pep:`484`-compliant **type hint metadata** (i.e.,
+    :class:`beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata`
+    instances describing test-specific :pep:`484`-compliant sample type hints
+    with metadata generically leveraged by various PEP-agnostic unit tests).
     '''
 
     # ..................{ IMPORTS                            }..................
@@ -298,14 +296,21 @@ def add_data(data_module: 'ModuleType') -> None:
         HintSignTypeVar,
         HintSignUnion,
     )
-    from beartype._util.hint.pep.proposal.pep484.utilpep484ref import (
-        HINT_PEP484_FORWARDREF_TYPE)
     from beartype._util.py.utilpyversion import (
+        IS_PYTHON_AT_MOST_3_11,
         IS_PYTHON_AT_LEAST_3_10,
         IS_PYTHON_AT_LEAST_3_9,
     )
+    from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
+        HintPepMetadata,
+        HintPithSatisfiedMetadata,
+        HintPithUnsatisfiedMetadata,
+    )
+
+    # ..................{ LOCALS                             }..................
+    # List of all PEP-specific type hint metadata to be returned.
+    hints_pep_meta = []
 
-    # ..................{ BOOLEANS                           }..................
     # True only if unsubscripted typing attributes (i.e., public attributes of
     # the "typing" module without arguments) are parametrized by one or more
     # type variables under the active Python interpreter.
@@ -324,41 +329,9 @@ def add_data(data_module: 'ModuleType') -> None:
     # 3.9, oddly. (We don't make the rules. We simply complain about them.)
     _IS_ARGS_HIDDEN = False
 
-    # ..................{ SETS                               }..................
-    # Add PEP 484-specific shallowly ignorable test type hints to that set
-    # global.
-    data_module.HINTS_PEP_IGNORABLE_SHALLOW.update((
-        # The "Generic" superclass imposes no constraints and is thus also
-        # semantically synonymous with the ignorable PEP-noncompliant
-        # "beartype.cave.AnyType" and hence "object" types. Since PEP
-        # 484 stipulates that *ANY* unsubscripted subscriptable PEP-compliant
-        # singleton including "typing.Generic" semantically expands to that
-        # singelton subscripted by an implicit "Any" argument, "Generic"
-        # semantically expands to the implicit "Generic[Any]" singleton.
-        Generic,
-    ))
-
-    # Add PEP 484-specific deeply ignorable test type hints to this set global.
-    data_module.HINTS_PEP_IGNORABLE_DEEP.update((
-        # Parametrizations of the "typing.Generic" abstract base class (ABC).
-        Generic[S, T],
-
-        # New type aliasing any ignorable type hint.
-        NewType('TotallyNotAny', Any),
-        NewType('TotallyNotObject', object),
-
-        # Optionals containing any ignorable type hint.
-        Optional[Any],
-        Optional[object],
-
-        # Unions containing any ignorable type hint.
-        Union[Any, float, str,],
-        Union[complex, int, object,],
-    ))
-
-    # ..................{ TUPLES ~ pep                       }..................
-    # Add PEP 484-specific test type hints to this dictionary global.
-    data_module.HINTS_PEP_META.extend((
+    # ..................{ LISTS                              }..................
+    # Add PEP-specific type hint metadata to this list.
+    hints_pep_meta.extend((
         # ................{ UNSUBSCRIPTED                      }................
         # Note that the PEP 484-compliant unsubscripted "NoReturn" type hint is
         # permissible *ONLY* as a return annotation and *MUST* thus be
@@ -371,34 +344,11 @@ def add_data(data_module: 'ModuleType') -> None:
             is_ignorable=True,
         ),
 
-        # Unsubscripted "ByteString" singleton. Bizarrely, note that:
-        # * "collections.abc.ByteString" is subscriptable under PEP 585.
-        # * "typing.ByteString" is *NOT* subscriptable under PEP 484.
-        # Since neither PEP 484 nor 585 comment on "ByteString" in detail (or
-        # at all, really), this non-orthogonality remains inexplicable,
-        # frustrating, and utterly unsurprising. We elect to merely shrug.
-        HintPepMetadata(
-            hint=ByteString,
-            pep_sign=HintSignByteString,
-            isinstanceable_type=collections_abc.ByteString,
-            piths_meta=(
-                # Byte string constant.
-                HintPithSatisfiedMetadata(
-                    b'By nautical/particle consciousness'),
-                # Byte array initialized from a byte string constant.
-                HintPithSatisfiedMetadata(
-                    bytearray(b"Hour's straight fates, (distemperate-ly)")),
-                # String constant.
-                HintPithUnsatisfiedMetadata(
-                    'At that atom-nestled canticle'),
-            ),
-        ),
-
         # Unsubscripted "Hashable" attribute.
         HintPepMetadata(
             hint=Hashable,
             pep_sign=HintSignHashable,
-            isinstanceable_type=collections_abc.Hashable,
+            isinstanceable_type=HashableABC,
             piths_meta=(
                 # String constant.
                 HintPithSatisfiedMetadata(
@@ -420,7 +370,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=Sized,
             pep_sign=HintSignSized,
-            isinstanceable_type=collections_abc.Sized,
+            isinstanceable_type=SizedABC,
             piths_meta=(
                 # String constant.
                 HintPithSatisfiedMetadata('Faire, a'),
@@ -458,8 +408,7 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Unsubscripted forward reference defined as a typing object.
         HintPepMetadata(
-            hint=HINT_PEP484_FORWARDREF_TYPE(
-                _TEST_PEP484_FORWARDREF_CLASSNAME),
+            hint=ForwardRef(_TEST_PEP484_FORWARDREF_CLASSNAME),
             pep_sign=HintSignForwardRef,
             piths_meta=(
                 # Instance of the class referred to by this reference.
@@ -581,7 +530,7 @@ def add_data(data_module: 'ModuleType') -> None:
             hint=Callable[[], str],
             pep_sign=HintSignCallable,
             typehint_cls=CallableTypeHint,
-            isinstanceable_type=collections_abc.Callable,
+            isinstanceable_type=CallableABC,
             piths_meta=(
                 # Lambda function returning a string constant.
                 HintPithSatisfiedMetadata(lambda: 'Eudaemonia.'),
@@ -1712,9 +1661,9 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Nested union of one non-"typing" type and one "typing" type.
         HintPepMetadata(
-            hint=Sequence[Union[str, ByteString]],
+            hint=Sequence[Union[str, bytes]],
             pep_sign=HintSignSequence,
-            isinstanceable_type=collections_abc.Sequence,
+            isinstanceable_type=SequenceABC,
             piths_meta=(
                 # Sequence of string and bytestring constants.
                 HintPithSatisfiedMetadata((
@@ -1728,7 +1677,7 @@ def add_data(data_module: 'ModuleType') -> None:
                     # Match that the exception message raised for this object
                     # declares the types *NOT* satisfied by this object.
                     exception_str_match_regexes=(
-                        r'\bByteString\b',
+                        r'\bbytes\b',
                         r'\bstr\b',
                     ),
                     # Match that the exception message raised for this object
@@ -1746,7 +1695,7 @@ def add_data(data_module: 'ModuleType') -> None:
                     exception_str_match_regexes=(
                         # Declares all non-"typing" types *NOT* satisfied by a
                         # random tuple item *NOT* satisfying this hint.
-                        r'\bByteString\b',
+                        r'\bbytes\b',
                         r'\bstr\b',
                         # Declares the index of the random tuple item *NOT*
                         # satisfying this hint.
@@ -1758,9 +1707,9 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Nested union of *NO* isinstanceable type and multiple "typing" types.
         HintPepMetadata(
-            hint=MutableSequence[Union[ByteString, Callable]],
+            hint=MutableSequence[Union[bytes, Callable]],
             pep_sign=HintSignMutableSequence,
-            isinstanceable_type=collections_abc.MutableSequence,
+            isinstanceable_type=MutableSequenceABC,
             piths_meta=(
                 # Mutable sequence of string and bytestring constants.
                 HintPithSatisfiedMetadata([
@@ -1773,7 +1722,7 @@ def add_data(data_module: 'ModuleType') -> None:
                     # Match that the exception message raised for this object
                     # declares the types *NOT* satisfied by this object.
                     exception_str_match_regexes=(
-                        r'\bByteString\b',
+                        r'\bbytes\b',
                         r'\bCallable\b',
                     ),
                     # Match that the exception message raised for this object
@@ -1795,7 +1744,7 @@ def add_data(data_module: 'ModuleType') -> None:
                     exception_str_match_regexes=(
                         # Declares all non-"typing" types *NOT* satisfied by a
                         # random list item *NOT* satisfying this hint.
-                        r'\bByteString\b',
+                        r'\bbytes\b',
                         r'\bCallable\b',
                         # Declares the index of the random list item *NOT*
                         # satisfying this hint.
@@ -1946,10 +1895,13 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
     ))
 
+    # ....................{ VERSION                        }....................
     # PEP-compliant type hints conditionally dependent on the major version of
     # Python targeted by the active Python interpreter.
+
+    # If the active Python interpreter targets at least Python <= 3.9...
     if IS_PYTHON_AT_LEAST_3_9:
-        data_module.HINTS_PEP_META.extend((
+        hints_pep_meta.append(
             # ..............{ GENERICS ~ user                    }..............
             # Subscripted generic subclassing a single unsubscripted "typing"
             # type. Note that these types constitute an edge case supported
@@ -1977,5 +1929,103 @@ def add_data(data_module: 'ModuleType') -> None:
                         'Freedom’s unappealing, Passive delights',
                     ]),
                 ),
-            ),
-        ))
+            )
+        )
+
+        # If the active Python interpreter targets at most Python <= 3.11...
+        if IS_PYTHON_AT_MOST_3_11:
+            # ..................{ IMPORTS                    }..................
+            # Defer importation of standard PEP 484-specific type hint factories
+            # deprecated under Python >= 3.12.
+            from collections.abc import ByteString as ByteStringABC
+            from typing import ByteString
+
+            # ..................{ MAPPINGS                   }..................
+            # Add PEP 484-specific test type hints to this dictionary global.
+            hints_pep_meta.append(
+                # ................{ UNSUBSCRIPTED              }................
+                # Unsubscripted "ByteString" singleton. Bizarrely, note that:
+                # * "collections.abc.ByteString" is subscriptable under PEP 585.
+                # * "typing.ByteString" is *NOT* subscriptable under PEP 484.
+                #
+                # Since neither PEP 484 nor 585 comment on "ByteString" in
+                # detail (or at all, really), this non-orthogonality remains
+                # inexplicable, frustrating, and utterly unsurprising. We elect
+                # to merely shrug.
+                HintPepMetadata(
+                    hint=ByteString,
+                    pep_sign=HintSignByteString,
+                    isinstanceable_type=ByteStringABC,
+                    piths_meta=(
+                        # Byte string constant.
+                        HintPithSatisfiedMetadata(
+                            b'By nautical/particle consciousness'),
+                        # Byte array initialized from a byte string constant.
+                        HintPithSatisfiedMetadata(
+                            bytearray(
+                                b"Hour's straight fates, (distemperate-ly)")),
+                        # String constant.
+                        HintPithUnsatisfiedMetadata(
+                            'At that atom-nestled canticle'),
+                    ),
+                )
+            )
+
+    # ..................{ RETURN                             }..................
+    # Return this list of all PEP-specific type hint metadata.
+    return hints_pep_meta
+
+
+def hints_pep484_ignorable_shallow() -> list:
+    '''
+    List of :pep:`544`-compliant **shallowly ignorable type hints** (i.e.,
+    ignorable on the trivial basis of their machine-readable representations).
+    '''
+
+    # Return this list of all PEP-specific shallowly ignorable type hints.
+    return [
+        # The "Any" catch-all. By definition, *ALL* objects annotated as "Any"
+        # unconditionally satisfy this catch-all and thus semantically reduce to
+        # unannotated objects.
+        Any,
+
+        # The root "object" superclass, which *ALL* objects annotated as
+        # "object" unconditionally satisfy under isinstance()-based type
+        # covariance and thus semantically reduce to unannotated objects.
+        # "object" is equivalent to the "typing.Any" type hint singleton.
+        object,
+
+        # The "Generic" superclass imposes no constraints and is thus also
+        # semantically synonymous with the ignorable PEP-noncompliant
+        # "beartype.cave.AnyType" and hence "object" types. Since PEP 484
+        # stipulates that *ANY* unsubscripted subscriptable PEP-compliant
+        # singleton including "typing.Generic" semantically expands to that
+        # singelton subscripted by an implicit "Any" argument, "Generic"
+        # semantically expands to the implicit "Generic[Any]" singleton.
+        Generic,
+    ]
+
+
+def hints_pep484_ignorable_deep() -> list:
+    '''
+    List of :pep:`544`-compliant **deeply ignorable type hints** (i.e.,
+    ignorable only on the non-trivial basis of their nested child type hints).
+    '''
+
+    # Return this list of all PEP-specific shallowly ignorable type hints.
+    return [
+        # Parametrizations of the "typing.Generic" abstract base class (ABC).
+        Generic[S, T],
+
+        # New type aliasing any ignorable type hint.
+        NewType('TotallyNotAny', Any),
+        NewType('TotallyNotObject', object),
+
+        # Optionals containing any ignorable type hint.
+        Optional[Any],
+        Optional[object],
+
+        # Unions containing any ignorable type hint.
+        Union[Any, float, str,],
+        Union[complex, int, object,],
+    ]
