@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 #
 # --------------------( SYNOPSIS                           )--------------------
@@ -163,9 +163,11 @@ exclude_patterns = [
 rst_prolog = '''
 .. tip::
 
-   `Feed the bear <GitHub Sponsors_>`__! `Animals wearing jewelry
-   <beadspace9_>`__! *What is even going on with this banner!?*
+   `Feed the bear! The bear is rooting around in your refuse pile <GitHub
+   Sponsors_>`__. You feel sadness – then trepidation.
 '''
+   # `Feed the bear <GitHub Sponsors_>`__! `Animals wearing jewelry
+   # <beadspace9_>`__! *What is even going on with this banner!?*
 
 # String of arbitrary reStructuredText (reST) to be implicitly appended to the
 # contents of *ALL* reST documents rendered by this configuration, initialized
